.. change::
    :tags: bug, sql
    :tickets: 9009
    :versions: 2.0.0rc1

    Added parameter
    :paramref:`.FunctionElement.column_valued.joins_implicitly`, which is
    useful in preventing the "cartesian product" warning when making use of
    table-valued or column-valued functions. This parameter was already
    introduced for :meth:`.FunctionElement.table_valued` in :ticket:`7845`,
    however it failed to be added for :meth:`.FunctionElement.column_valued`
    as well.
